==> tuia-advert-center-api-2.4.73-sources.jar: cn/com/duiba/tuia/core/api/dto/req/PromoteTestCheckReq.java <==
package cn.com.duiba.tuia.core.api.dto.req;


import java.io.Serializable;
import java.util.List;

/**
 * 落地页审核审核入参
 */
public class PromoteTestCheckReq implements Serializable {
    private static final long serialVersionUID = 1L;

    private Long id;

    //1通过 2拒绝
    private Integer auditResult;

    private List<Long> materialIds;

    private String rejectReason;

    private String auditor;

    //落地页标签
    private String promoteTag;

    /** 广告主名称 **/
    private String companyName;


    /**审核类型来源，1.广告系统审核2.钟馗跳转广告系统复审*/
    private Integer checkType;
/**如果是钟馗转跳复审 需要把/materialPromoteRecheck/list 接口里的id传过来*/
    private Long riskSourceId;
    /**当前可以看见的落地页列表id 多个用字符串,拼接*/
    private String seeSourcePromoteIds;
    /**当前可以看见的关联素材列表id，多个用字符串,拼接
     */
    private String seeSourceMateriaIds;


    public Integer getCheckType() {
        return checkType;
    }

    public void setCheckType(Integer checkType) {
        this.checkType = checkType;
    }

    public Long getRiskSourceId() {
        return riskSourceId;
    }

    public void setRiskSourceId(Long riskSourceId) {
        this.riskSourceId = riskSourceId;
    }

    public String getSeeSourcePromoteIds() {
        return seeSourcePromoteIds;
    }

    public void setSeeSourcePromoteIds(String seeSourcePromoteIds) {
        this.seeSourcePromoteIds = seeSourcePromoteIds;
    }

    public String getSeeSourceMateriaIds() {
        return seeSourceMateriaIds;
    }

    public void setSeeSourceMateriaIds(String seeSourceMateriaIds) {
        this.seeSourceMateriaIds = seeSourceMateriaIds;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getAuditResult() {
        return auditResult;
    }

    public void setAuditResult(Integer auditResult) {
        this.auditResult = auditResult;
    }

    public List<Long> getMaterialIds() {
        return materialIds;
    }

    public void setMaterialIds(List<Long> materialIds) {
        this.materialIds = materialIds;
    }

    public String getRejectReason() {
        return rejectReason;
    }

    public void setRejectReason(String rejectReason) {
        this.rejectReason = rejectReason;
    }

    public String getAuditor() {
        return auditor;
    }

    public void setAuditor(String auditor) {
        this.auditor = auditor;
    }

    public String getPromoteTag() {
        return promoteTag;
    }

    public void setPromoteTag(String promoteTag) {
        this.promoteTag = promoteTag;
    }
}

==> tuia-advert-center-api-2.6.05-sources.jar: cn/com/duiba/tuia/core/api/dto/req/PromoteTestCheckReq.java <==
package cn.com.duiba.tuia.core.api.dto.req;


import cn.com.duiba.tuia.core.api.dto.jump.SecondJumpInfoDto;

import java.io.Serializable;
import java.util.List;

/**
 * 落地页审核审核入参
 */
public class PromoteTestCheckReq implements Serializable {
    private static final long serialVersionUID = 1L;

    private Long id;

    //1通过 2拒绝
    private Integer auditResult;

    private List<Long> materialIds;

    private String rejectReason;

    private String auditor;

    //落地页标签
    private String promoteTag;

    /** 广告主名称 **/
    private String companyName;


    /**审核类型来源，1.广告系统审核2.钟馗跳转广告系统复审*/
    private Integer checkType;
/**如果是钟馗转跳复审 需要把/materialPromoteRecheck/list 接口里的id传过来*/
    private Long riskSourceId;
    /**当前可以看见的落地页列表id 多个用字符串,拼接*/
    private String seeSourcePromoteIds;
    /**当前可以看见的关联素材列表id，多个用字符串,拼接
     */
    private String seeSourceMateriaIds;

    /**
     * 二跳的信息
     */
    private List<SecondJumpInfoDto> secondJumpInfo;

    public Integer getCheckType() {
        return checkType;
    }

    public void setCheckType(Integer checkType) {
        this.checkType = checkType;
    }

    public Long getRiskSourceId() {
        return riskSourceId;
    }

    public void setRiskSourceId(Long riskSourceId) {
        this.riskSourceId = riskSourceId;
    }

    public String getSeeSourcePromoteIds() {
        return seeSourcePromoteIds;
    }

    public void setSeeSourcePromoteIds(String seeSourcePromoteIds) {
        this.seeSourcePromoteIds = seeSourcePromoteIds;
    }

    public String getSeeSourceMateriaIds() {
        return seeSourceMateriaIds;
    }

    public void setSeeSourceMateriaIds(String seeSourceMateriaIds) {
        this.seeSourceMateriaIds = seeSourceMateriaIds;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getAuditResult() {
        return auditResult;
    }

    public void setAuditResult(Integer auditResult) {
        this.auditResult = auditResult;
    }

    public List<Long> getMaterialIds() {
        return materialIds;
    }

    public void setMaterialIds(List<Long> materialIds) {
        this.materialIds = materialIds;
    }

    public String getRejectReason() {
        return rejectReason;
    }

    public void setRejectReason(String rejectReason) {
        this.rejectReason = rejectReason;
    }

    public String getAuditor() {
        return auditor;
    }

    public void setAuditor(String auditor) {
        this.auditor = auditor;
    }

    public String getPromoteTag() {
        return promoteTag;
    }

    public void setPromoteTag(String promoteTag) {
        this.promoteTag = promoteTag;
    }

    public List<SecondJumpInfoDto> getSecondJumpInfo() {
        return secondJumpInfo;
    }

    public void setSecondJumpInfo(List<SecondJumpInfoDto> secondJumpInfo) {
        this.secondJumpInfo = secondJumpInfo;
    }
}
